Crate win_service_logger

Crate win_service_logger 

A logger which writes log messages to the Windows Event Viewer

Example

extern crate win_service_logger;
#[macro_use] extern crate log;

fn main() {
    win_service_logger::init();
    trace!("Hello from Rust!");

    warn!("This will be a warning in Event Viewer!");
    error!("Bad");
}

Structs

Logger

Statics

LOGGER

Functions

init
Initializes the global logger with a windows service logger
init_with_name
Initializes the global logger with a windows service logger
try_init
Initializes the global logger with a windows service logger
try_init_with_name
Initializes the global logger with a windows service logger.