A logger which writes log messages to the Windows Event Viewer
Example
extern crate win_service_logger;
#[macro_use] extern crate log;
fn main() {
win_service_logger::init();
trace!("Hello from Rust!");
warn!("This will be a warning in Event Viewer!");
error!("Bad");
}Structs
Statics
Functions
- init
- Initializes the global logger with a windows service logger
- init_
with_ name - Initializes the global logger with a windows service logger
- try_
init - Initializes the global logger with a windows service logger
- try_
init_ with_ name - Initializes the global logger with a windows service logger.